#[repr(u8)]pub enum PayloadCommandStatus {
Success = 0,
Pending = 1,
Offline = 2,
Exceptions = 3,
Error = 4,
}Expand description
Result of the execute operation.
Variants
Success = 0
Confirm that the command succeeded.
Pending = 1
Command is enqueued but expected to succeed.
Offline = 2
Target device is in offline state or unreachable.
Exceptions = 3
There is an issue or alert associated with a command. The command could succeed or fail. This status type is typically set when you want to send additional information about another connected device.
Error = 4
Target device is unable to perform the command.