pub struct Payload {
pub error_code: Option<String>,
pub debug_string: Option<String>,
pub commands: Vec<PayloadCommand>,
}Expand description
EXECUTE response payload.
Fields
error_code: Option<String>An error code for the entire transaction for auth failures and developer system unavailability. For individual device errors, use the errorCode within the device object.
debug_string: Option<String>Detailed error which will never be presented to users but may be logged or used during development.
commands: Vec<PayloadCommand>Each object contains one or more devices with response details. N.B. These may not be grouped the same way as in the request. For example, the request might turn 7 lights on, with 3 lights succeeding and 4 failing, thus with two groups in the response