pub struct PayloadCommand {
pub ids: Vec<String>,
pub status: PayloadCommandStatus,
pub states: Map<String, Value>,
pub error_code: Option<String>,
}Expand description
Device execution result.
Fields
ids: Vec<String>List of device IDs corresponding to this status.
status: PayloadCommandStatusResult of the execute operation.
states: Map<String, Value>Aligned with per-trait states described in each trait schema reference. These are the states after execution, if available.
error_code: Option<String>Expanding ERROR state if needed from the preset error codes, which will map to the errors presented to users.